@@ -200,7 +200,7 @@ public:
     void processDhcp6QueryAndSendResponse(Pkt6Ptr& query, Pkt6Ptr& rsp);
 
     /// @brief Instructs the server to shut down.
-    void shutdown();
+    void shutdown() override;
 
     ///
     /// @name Public accessors returning values required to (re)open sockets.
