@@ -94,7 +94,8 @@ const SimpleKeywords SimpleParser4::GLOBAL4_PARAMETERS = {
     { "cache-max-age",                  Element::integer },
     { "ip-reservations-unique",         Element::boolean },
     { "ddns-update-on-renew",           Element::boolean },
-    { "ddns-use-conflict-resolution",   Element::boolean }
+    { "ddns-use-conflict-resolution",   Element::boolean },
+    { "compatibility",                  Element::map },
 };
 
 /// @brief This table defines default global values for DHCPv4
